# 神奇小说爬虫
## 第一版主爬虫

### 介绍
爬取第一版主的爬虫

### 安装教程

无

### 使用说明

1、 cd到项目路径下,通过运行cmd命令 pip install -r requirements.txt 来安装第三方库 <br/>
2、 创建mysql数据库sex,执行sql语句 修改YuLinZhanYeScrapy.py 中的ip,用户名,密码 <br/>
3、 运行main.py <br/>